pub trait AsBorrowed<S> {
type Borrowed: ?Sized;
// Required method
fn as_borrowed(&self) -> &Self::Borrowed;
}Expand description
Trait that can be used as a key to query a compound. Basically something
that can be converted to a type B such that S: Borrow<B>.
Required Associated Types
Required Methods
fn as_borrowed(&self) -> &Self::Borrowed
Implementors
Sourceimpl<'a, Q> AsBorrowed<Cow<'a, str>> for Q
impl<'a, Q> AsBorrowed<Cow<'a, str>> for Q
Sourceimpl<Q> AsBorrowed<Cow<'_, JavaStr>> for Q
Available on crate feature java_string only.
impl<Q> AsBorrowed<Cow<'_, JavaStr>> for Q
Available on crate feature
java_string only.Sourceimpl<Q> AsBorrowed<JavaString> for Q
Available on crate feature java_string only.
impl<Q> AsBorrowed<JavaString> for Q
Available on crate feature
java_string only.